Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(102)

Unified Diff: net/log/test_net_log.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/log/test_net_log.h
diff --git a/net/log/test_net_log.h b/net/log/test_net_log.h
index 6190ab873c58ec95ca91e06e7be91ee22c2c30af..7568c4821e9088c3ecba9dc82513b576688e15c7 100644
--- a/net/log/test_net_log.h
+++ b/net/log/test_net_log.h
@@ -48,18 +48,18 @@ class TestNetLog : public NetLog {
DISALLOW_COPY_AND_ASSIGN(TestNetLog);
};
// Helper class that exposes a similar API as BoundNetLog, but uses a
// TestNetLog rather than the more generic NetLog.
//
// A BoundTestNetLog can easily be converted to a BoundNetLog using the
// bound() method.
class BoundTestNetLog {
public:
BoundTestNetLog();
~BoundTestNetLog();
- // The returned BoundNetLog is only valid while |this| is alive.
- BoundNetLog bound() const { return net_log_; }
+ // The returned NetLogWithSource is only valid while |this| is alive.
+ NetLogWithSource bound() const { return net_log_; }
// Fills |entry_list| with all entries in the log.
void GetEntries(TestNetLogEntry::List* entry_list) const;
@@ -78,7 +78,7 @@ class BoundTestNetLog {
private:
TestNetLog test_net_log_;
- const BoundNetLog net_log_;
+ const NetLogWithSource net_log_;
DISALLOW_COPY_AND_ASSIGN(BoundTestNetLog);
};
@@ -48,18 +48,18 @@ class TestNetLog : public NetLog {
DISALLOW_COPY_AND_ASSIGN(TestNetLog);
};
-// Helper class that exposes a similar API as BoundNetLog, but uses a
+// Helper class that exposes a similar API as NetLogWithSource, but uses a
// TestNetLog rather than the more generic NetLog.
//
@@ -48,18 +48,18 @@ class TestNetLog : public NetLog {
// TestNetLog rather than the more generic NetLog.
//
-// A BoundTestNetLog can easily be converted to a BoundNetLog using the
+// A BoundTestNetLog can easily be converted to a NetLogWithSource using the
// bound() method.
class BoundTestNetLog {

Powered by Google App Engine
This is Rietveld 408576698